Function to allocate markers with redundant information into bins.
Within each bin, the pairwise recombination fraction between markers is zero.
Usage
find_bins(input.obj, exact = TRUE, ch = NULL)
Arguments
input.obj
an object of class onemap.
exact
logical. If TRUE, it only allocates markers with
the exact same information into bins, including missing data; if
FALSE, missing data are not considered when allocating markers.
In the latter case, the marker with the lowest amount of missing data is
taken as the representative marker on that bin.
ch
not used in this OneMap version. Chromosome for which the
analysis should be performed. If NULL the analisys is performed
for all chromosomes.
Value
An object of class onemap_bin, which is a list containing the
following components:
bins
a list containing the bins. Each element of
the list is a table whose lines indicate the name of the marker, the bin in
which that particular marker was allocated and the percentage of missing data.
The name of each element of the list corresponds to the marker with the lower
amount of missing data among those on the bin
n.mar
total number of markers.
n.ind
number individuals
exact.search
logical; indicates if
the search was performed with the argument exact=TRUE or exact=FALSE
# NOT RUN {# }# NOT RUN { load(url("https://github.com/mmollina/data/raw/master/fake_big_data_f2.RData"))
fake.big.data.f2
(bins<-find_bins(fake.big.data.f2, exact=FALSE))
# }