For a given sequence of markers, apply mds method described in Preedy and Hackett (2016) using MDSMap package to ordering markers and estimates the genetic distances with OneMap multipoint approach. Also gives MDSMap input file format for directly analysis in this package.
mds_onemap(input.seq, out.file = "out.file",
mds.graph.file = "NULL.pdf", p = NULL, n = NULL, ispc = TRUE,
displaytext = FALSE, weightfn = "lod2", mapfn = "haldane",
hmm = TRUE, mds.seq = TRUE)an object of class sequence
path to the generated MDSMap input file.
path to the graphic generated by MDSMap
Integer - the penalty for deviations from the sphere - higher p forces points more closely onto a sphere.
Vector of integers or strings containing markers to be omitted from the analysis.
Logical determining the method to be used to estimate the map. By default this is TRUE and the method of principal curves will be used. If FALSE then the constrained MDS method will be used.
Shows markers names in analysis graphic view
Character string specifying the values to use for the weight matrix in the MDS 'lod2' or 'lod'.
Character string specifying the map function to use on the recombination fractions 'haldane' is default, 'kosambi' or 'none'.
Multipoint genetic distance estimation
When some pair of markers do not follow the linkage criteria,
if TRUE one of the markers is removed and mds is performed again.
An object of class sequence, which is a list containing the
following components:
a vector containing the
(ordered) indices of markers in the sequence, according to the input file.
a vector with the linkage phases between markers
in the sequence, in corresponding positions. -1 means that there are
no defined linkage phases.
a vector with the
recombination frequencies between markers in the sequence. -1 means
that there are no estimated recombination frequencies.
log-likelihood of the corresponding linkage map.
name of the object of class onemap with the raw
data.
name of the object of class rf_2pts with the
2-point analyses.
For better description about MDS method, see MDSMap package vignette.
Preedy, K. F. and Hackett, C. A. (2016). A rapid marker ordering approach for high-density genetic linkage maps in experimental autotetraploid populations using multidimensional scaling. Theoretical and Applied Genetics 129: 2117-2132
Mollinari, M., Margarido, G. R. A., Vencovsky, R. and Garcia, A. A. F. (2009) Evaluation of algorithms used to order markers on genetics maps. Heredity 103: 494-502.
Wu, R., Ma, C.-X., Painter, I. and Zeng, Z.-B. (2002a) Simultaneous maximum likelihood estimation of linkage and linkage phases in outcrossing species. Theoretical Population Biology 61: 349-363.
Wu, R., Ma, C.-X., Wu, S. S. and Zeng, Z.-B. (2002b). Linkage mapping of sex-specific differences. Genetical Research 79: 85-96