/doc of the package distribution.The most important functions are:
read.outcrossfor data importing.rf.2ptsto perform two-point
analyses between all pairs of markers.marker.typeto check the segregation type of
a marker.make.seqto define a sequence of markers,
which are the input of most mapping functions.groupto assign markers to linkage
groups.compareto compare all possible orders
of markers in a sequence.try.seqto try a given marker in every
position of a framework of mapped markers.order.seqto automate the process of mapping
a sequence of markers, combining compare and try.seq functions.rippleto check a set of mapped markers,
looking for (plausible) alternative orders.mapto construct a map for a sequence
in a given order.Kosambi, D. D. (1944) The estimation of map distance from recombination values. Annuaire of Eugenetics 12: 172-175. Lander, E. S. and Green, P. (1987). Construction of multilocus genetic linkage maps in humans. Proc. Natl. Acad. Sci. USA 84: 2363-2367.
Lander, E. S., Green, P., Abrahamson, J., Barlow, A., Daly, M. J., Lincoln, S. E. and Newburg, L. (1987) MAPMAKER: An interactive computer package for constructing primary genetic linkage maps of experimental and natural populations. Genomics 1: 174-181.
Lincoln, S. E., Daly, M. J. and Lander, E. S. (1993) Constructing genetic linkage maps with MAPMAKER/EXP Version 3.0: a tutorial and reference manual. A Whitehead Institute for Biomedical Research Technical Report. Margarido, G. R. A., Souza, A.P. and Garcia, A. A. F. (2007) OneMap: software for genetic mapping in outcrossing species. Hereditas 144: 78-79. Oliveira, K. M., Pinto, L. R., Marconi, T. G., Margarido, G. R. A., Pastina, M. M., Teixeira, L. H. M., Figueira, A. V. O., Ulian, E. C., Garcia, A. A. F. and Souza, A. P. (2007) Functional genetic linkage map based on EST-markers for a sugarcane (Saccharum spp.) commercial cross. Molecular Breeding 20: 189-208.
Oliveira, E. J., Vieira, M. L. C., Garcia, A. A. F., Munhoz, C. F.,Margarido, G. R.A., Consoli, L., Matta, F. P., Moraes, M. C., Zucchi, M. I., and Fungaro,M. H. P. (2008) An Integrated Molecular Map of Yellow Passion Fruit Based on Simultaneous Maximum-likelihood Estimation of Linkage and Linkage Phases J. Amer. Soc. Hort. Sci. 133: 35-41. Wu, R., Ma, C.-X., Painter, I. and Zeng, Z.-B. (2002a) Simultaneous maximum likelihood estimation of linkage and linkage phases in outcrossing species. Theoretical Population Biology 61: 349-363.
Wu, R., Ma, C.-X., Wu, S. S. and Zeng, Z.-B. (2002b). Linkage mapping of sex-specific differences. Genetical Research 79: 85-96