ord_by_geno: Order the markers in a sequence using the genomic position

View source: R/utils.R

ord_by_genoR Documentation

Order the markers in a sequence using the genomic position

Description

Order the markers in a sequence using the genomic position

Usage

ord_by_geno(input.seq)

Arguments

input.seq

object of class 'sequence'

Value

An object of class sequence

Author(s)

Cristiane Taniguti


onemap documentation built on July 11, 2026, 9:07 a.m.