outcross.read.outcross(dir, file)outcross, i.e., a list with the following
components:strings."A"; 2 corresponds to markers
of type "B1.5"; 3 corresponds to markers of type "B2.6";
4 corresponds to markers of type "B3.7"; 5 corresponds to
markers of type "C.8"; 6 corresponds to markers of type
"D1" and 7 corresponds to markers of type "D2"MAPMAKER/EXP (Lincoln et al., 1993). The first line
contains two integers: the number of individuals and the number of
markers. Next comes the genotype data for all markers. Each new marker is
initiated with a "A.1", "A.2", "A.3", "A.4", "B1.5",
"B2.6", "B3.7", "C.8", "D1.9",
"D1.10", "D1.11", "D1.12", "D1.13",
"D2.14", "D2.15", "D2.16", "D2.17" or
"D2.18" (without quotes) [see marker.type and
Wu et al. (2002) for details].
Finally, after the segregation type comes the genotype data for the
corresponding marker. Depending on the segregation type, genotypes may
be denoted by ac, ad, bc, bd, a,
ba, b, bc, ab and o, in several
possible combinations. To make things easier, we have followed exactly
the notation used by Wu et al. (2002). Genotypes must be
separated by commas. Missing values are denoted by "-"
The example directory in the package distribution contains
an example data file to be read with this function. Further
instructions can be found at the tutorial distributed along with this
package.
Wu, R., Ma, C.-X., Painter, I. and Zeng, Z.-B. (2002) Simultaneous maximum likelihood estimation of linkage and linkage phases in outcrossing species. Theoretical Population Biology 61: 349-363.
example directory in the package source.outcr_data <-
read.outcross(dir="work_directory",file="data_file.txt")Run the code above in your browser using DataLab