## S3 method for class 'rf.2pts':
print(x, mrk1 = NULL, mrk2 = NULL, \dots)
Arguments
w
an object of class outcross.
LOD
minimum LOD Score to declare linkage (defaults to
3).
max.rf
maximum recombination fraction to declare linkage
(defaults to 0.50).
verbose
logical. If TRUE, current progress is shown; if
FALSE, no output is produced.
x
an object of class rf.2pts.
mrk1, mrk2
optionally, two markers can be specified. If so,
detailed results of the two-point analysis will be printed for this
pair. Both arguments can be numeric or character strings indicating
the numbers/names corresponding to any markers in the inpu
...
further arguments, passed to other methods. Currently
ignored.
Value
An object of class rf.2pts, which is a list containing the
following components:
data.namename of the object of class outcross with the
raw data.
n.martotal number of markers.
marnamesmarker names, according to the input file.
LODminimum LOD Score to declare linkage.
max.rfmaximum recombination fraction to declare linkage.
inputthe name of the input file.
analysisan array with the complete results of the two-point
analysis for each pair of markers.
Details
For n markers, there are $$\frac{n(n-1)}{2}$$
pairs of markers to be analyzed. Therefore, completion of the
two-point analyses can take a long time.
References
Wu, R., Ma, C.-X., Painter, I. and Zeng, Z.-B. (2002) Simultaneous
maximum likelihood estimation of linkage and linkage phases in
outcrossing species. Theoretical Population Biology 61:
349-363.