Learn R Programming

onemap (version 1.0-0)

ripple: Compares and displays plausible alternative orders for a given linkage map

Description

For a given sequence of ordered markers, computes the multipoint likelihood of alternative orders, by shuffling subsets (windows) of markers within the sequence. For each position of the window, all possible $(ws)!$ orders are compared.

Usage

ripple(w,ws=4,LOD=3,tol=10E-5)

Arguments

w
an object of class sequence with a predefined order.
ws
an integer specifying the length of the window size (defaults to 4).
LOD
threshold for the LOD-Score, so that alternative orders with LOD less then or equal to this threshold will be displayed.
tol
tolerance for the C routine, i.e., the value used to evaluate convergence.

Value

  • This function does not return any value; it just produces text output to suggest alternative orders.

Details

Large values for the window size make computations very slow, specially if there are many non-completely informative markers.

References

Broman, K. W., Wu, H., Churchill, G., Sen, S., Yandell, B. (2008) qtl: Tools for analyzing QTL experiments R package version 1.09-43 Jiang, C. and Zeng, Z.-B. (1997). Mapping quantitative trait loci with dominant and missing markers in various crosses from two inbred lines. Genetica 101: 47-58.

Lander, E. S., Green, P., Abrahamson, J., Barlow, A., Daly, M. J., Lincoln, S. E. and Newburg, L. (1987) MAPMAKER: An interactive computer package for constructing primary genetic linkage maps of experimental and natural populations. Genomics 1: 174-181.

Wu, R., Ma, C.-X., Painter, I. and Zeng, Z.-B. (2002a) Simultaneous maximum likelihood estimation of linkage and linkage phases in outcrossing species. Theoretical Population Biology 61: 349-363. Wu, R., Ma, C.-X., Wu, S. S. and Zeng, Z.-B. (2002b). Linkage mapping of sex-specific differences. Genetical Research 79: 85-96

See Also

make.seq, compare, try.seq and order.seq.

Examples

Run this code
data(example_out)
  twopt <- rf.2pts(example_out)
  
  markers <- make.seq(twopt,c(27,16,20,4,19,21,23,9,24,29))
  markers.map <- map(markers)
  ripple(markers.map)

Run the code above in your browser using DataLab