Learn R Programming

onemap (version 2.0-1)

rf.2pts: Two-point analysis between genetic markers

Description

Performs the two-point (pairwise) analysis proposed by Wu et al. (2002) between all pairs of markers.

Usage

rf.2pts(input.obj, LOD = 3, max.rf = 0.50, verbose = TRUE)

## S3 method for class 'rf.2pts': print(x, mrk1 = NULL, mrk2 = NULL, \dots)

Arguments

input.obj
an object of class outcross, bc.onemap, f2.onemap, riself.onemap or risib.onemap.
LOD
minimum LOD Score to declare linkage (defaults to 3).
max.rf
maximum recombination fraction to declare linkage (defaults to 0.50).
verbose
logical. If TRUE, current progress is shown; if FALSE, no output is produced.
x
an object of class rf.2pts.
mrk1, mrk2
optionally, two markers can be specified. If so, detailed results of the two-point analysis will be printed for this pair. Both arguments can be numeric or character strings indicating the numbers/names corresponding to any markers in the inpu
...
further arguments, passed to other methods. Currently ignored.

Value

  • An object of class rf.2pts, which is a list containing the following components:
  • data.namename of the object with the raw data.
  • n.martotal number of markers.
  • marnamesmarker names, according to the input file.
  • LODminimum LOD Score to declare linkage.
  • max.rfmaximum recombination fraction to declare linkage.
  • inputthe name of the input file.
  • analysisan array with the complete results of the two-point analysis for each pair of markers.

Details

For n markers, there are $$\frac{n(n-1)}{2}$$ pairs of markers to be analyzed. Therefore, completion of the two-point analyses can take a long time.

References

Wu, R., Ma, C.-X., Painter, I. and Zeng, Z.-B. (2002) Simultaneous maximum likelihood estimation of linkage and linkage phases in outcrossing species. Theoretical Population Biology 61: 349-363.

Examples

Run this code
data(example.out)

  twopts <- rf.2pts(example.out,LOD=3,max.rf=0.5) # perform two-point analyses
  twopts

  print(twopts,"M1","M2") # detailed results for markers 1 and 2

Run the code above in your browser using DataLab